| gwas2crispr-package | R Documentation |
Provides a reproducible pipeline to conduct genome-wide association studies (GWAS) and extract single-nucleotide polymorphisms (SNPs) for a human trait or disease. Given aggregated GWAS dataset(s) and a user-defined significance threshold, the package retrieves significant SNPs from the GWAS Catalog using supported trait identifiers, annotates their gene context, and can write a harmonised metadata table in comma-separated values (CSV) format, genomic intervals in the Browser Extensible Data (BED) format, and sequences in the FASTA (text-based sequence) format with user-defined flanking regions for clustered regularly interspaced short palindromic repeats (CRISPR) guide design. The existing efo_id argument is retained for backward compatibility. The package prepares computational artifacts for downstream workflows; it does not perform biological causality testing, clinical interpretation, therapeutic design, or wet-lab validation. For details on the resources and methods see: Buniello et al. (2019) \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1093/nar/gky1120")}; Sollis et al. (2023) \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1093/nar/gkac1010")}; Jinek et al. (2012) \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1126/science.1225829")}.
Maintainer: Othman S. I. Mohammed admin@leopard.ly
Other contributors:
LEOPARD.LY LTD [copyright holder]
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.